@@ -26,6 +26,9 @@ FAILEDOPERATION_ACTIONUNREACHABLE = 'FailedOperation.ActionUnreachable'
 # 广播任务正在执行。
 FAILEDOPERATION_BROADCASTTASKISRUNNING = 'FailedOperation.BroadcastTaskIsRunning'
 
+# 产品未开通视频AI分析服务
+FAILEDOPERATION_CLOUDSTORAGEAISERVICENOTENABLED = 'FailedOperation.CloudStorageAIServiceNotEnabled'
+
 # 设备已经被禁用。
 FAILEDOPERATION_DEVICEALREADYDISABLED = 'FailedOperation.DeviceAlreadyDisabled'
 
@@ -44,12 +47,18 @@ FAILEDOPERATION_DEVICEOFFLINE = 'FailedOperation.DeviceOffline'
 # 存在其他升级任务。
 FAILEDOPERATION_OTHERUPDATETASKEXIST = 'FailedOperation.OtherUpdateTaskExist'
 
+# 产品未开通 IoT Video 服务
+FAILEDOPERATION_PRODUCTIOTVIDEOSERVICENOTENABLED = 'FailedOperation.ProductIotVideoServiceNotEnabled'
+
 # 产品尚未发布。
 FAILEDOPERATION_PRODUCTNOTRELEASED = 'FailedOperation.ProductNotReleased'
 
 # RRPC接口未收到设备端响应。
 FAILEDOPERATION_RRPCTIMEOUT = 'FailedOperation.RRPCTimeout'
 
+# 请求TRTC失败
+FAILEDOPERATION_REQUESTTRTCFAIL = 'FailedOperation.RequestTRTCFail'
+
 # 转发已经停止。
 FAILEDOPERATION_RULEALREADYDISABLED = 'FailedOperation.RuleAlreadyDisabled'
 
@@ -98,6 +107,12 @@ INVALIDPARAMETER_FIRMWAREALREADYEXIST = 'InvalidParameter.FirmwareAlreadyExist'
 # 产品不是网关类型，无法绑定子产品。
 INVALIDPARAMETER_PRODUCTISNOTGATEWAY = 'InvalidParameter.ProductIsNotGateway'
 
+# RoomId已存在
+INVALIDPARAMETER_ROOMIDEXIST = 'InvalidParameter.RoomIdExist'
+
+# UserId数量超出限制
+INVALIDPARAMETER_USERIDOVERLIMIT = 'InvalidParameter.UserIdOverLimit'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
@@ -155,6 +170,15 @@ INVALIDPARAMETERVALUE_FIRMWAREALREADYEXIST = 'InvalidParameterValue.FirmwareAlre
 # 转发重定向被拒绝。
 INVALIDPARAMETERVALUE_FORWARDREDIRECTDENIED = 'InvalidParameterValue.ForwardRedirectDenied'
 
+# 拉取产品列表失败。
+INVALIDPARAMETERVALUE_GETPRODUCTSLISTERROR = 'InvalidParameterValue.GetProductsListError'
+
+# 回调 Token 格式有误
+INVALIDPARAMETERVALUE_INVALIDCALLBACKTOKEN = 'InvalidParameterValue.InvalidCallbackToken'
+
+# 回调 URL 无效或格式有误
+INVALIDPARAMETERVALUE_INVALIDCALLBACKURL = 'InvalidParameterValue.InvalidCallbackUrl'
+
 # SQL语句含有非法字符。
 INVALIDPARAMETERVALUE_INVALIDSQL = 'InvalidParameterValue.InvalidSQL'
 
@@ -221,6 +245,9 @@ INVALIDPARAMETERVALUE_MSGTITLEINVALID = 'InvalidParameterValue.MsgTitleInvalid'
 # 消息类型非法。
 INVALIDPARAMETERVALUE_MSGTYPEINVALID = 'InvalidParameterValue.MsgTypeInvalid'
 
+# 无权限。
+INVALIDPARAMETERVALUE_NOPERMISSION = 'InvalidParameterValue.NoPermission'
+
 # 操作不支持。
 INVALIDPARAMETERVALUE_OPERATIONDENIED = 'InvalidParameterValue.OperationDenied'
 
@@ -329,9 +356,18 @@ RESOURCENOTFOUND_BATCHPRODUCTIONNOTEXIST = 'ResourceNotFound.BatchProductionNotE
 # 上传URL无法获取。
 RESOURCENOTFOUND_CANNOTGETFROMURL = 'ResourceNotFound.CannotGetFromUrl'
 
+# 云存AI分析任务不存在
+RESOURCENOTFOUND_CLOUDSTORAGEAISERVICETASK = 'ResourceNotFound.CloudStorageAIServiceTask'
+
+# 云存AI分析任务输出文件不存在
+RESOURCENOTFOUND_CLOUDSTORAGEAISERVICETASKFILE = 'ResourceNotFound.CloudStorageAIServiceTaskFile'
+
 # 存在重复设备。
 RESOURCENOTFOUND_DEVICEDUPKEYEXIST = 'ResourceNotFound.DeviceDupKeyExist'
 
+# 设备固件信息不存在。
+RESOURCENOTFOUND_DEVICEFIRMWARENOTEXIST = 'ResourceNotFound.DeviceFirmWareNotExist'
+
 # 固件不存在。
 RESOURCENOTFOUND_DEVICEHASNOFIRMWARE = 'ResourceNotFound.DeviceHasNoFirmware'
 
@@ -341,7 +377,7 @@ RESOURCENOTFOUND_DEVICENOTBIND = 'ResourceNotFound.DeviceNotBind'
 # 设备不存在。
 RESOURCENOTFOUND_DEVICENOTEXIST = 'ResourceNotFound.DeviceNotExist'
 
-# 设备没有影子信息。
+# 设备影子未创建或是已删除。
 RESOURCENOTFOUND_DEVICESHADOWNOTEXIST = 'ResourceNotFound.DeviceShadowNotExist'
 
 # 围栏未绑定该设备。
@@ -431,6 +467,9 @@ UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOINSTANCE = 'UnauthorizedOperation.NoPe
 # 产品ACL错误。
 UNAUTHORIZEDOPERATION_NOPERMISSIONTOSTUDIOPRODUCT = 'UnauthorizedOperation.NoPermissionToStudioProduct'
 
+# 无权操作该房间
+UNAUTHORIZEDOPERATION_NOPERMISSIONTOTRTCROOM = 'UnauthorizedOperation.NoPermissionToTRTCRoom'
+
 # 您的帐号未实名认证，请登录腾讯云进行实名认证
 UNAUTHORIZEDOPERATION_NOVERIFIED = 'UnauthorizedOperation.NoVerified'
 
@@ -443,6 +482,9 @@ UNAUTHORIZEDOPERATION_PRODUCTNOTSUPPORTPSK = 'UnauthorizedOperation.ProductNotSu
 # License数量不足。
 UNAUTHORIZEDOPERATION_USERLICENSEEXCEEDLIMIT = 'UnauthorizedOperation.UserLicenseExceedLimit'
 
+# 未知参数错误。
+UNKNOWNPARAMETER = 'UnknownParameter'
+
 # 操作不支持。
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
 
@@ -509,6 +551,9 @@ UNSUPPORTEDOPERATION_PRODUCTEXISTUNDERPROJECT = 'UnsupportedOperation.ProductExi
 # 产品被绑定到网关产品。
 UNSUPPORTEDOPERATION_PRODUCTHASBINDEDGATEWAYPRODUCT = 'UnsupportedOperation.ProductHasBindedGateWayProduct'
 
+# 产品已被共享，请先解除共享。
+UNSUPPORTEDOPERATION_PRODUCTHASSHARED = 'UnsupportedOperation.ProductHasShared'
+
 # 存在重复项目。
 UNSUPPORTEDOPERATION_PROJECTDUPKEYEXIST = 'UnsupportedOperation.ProjectDupKeyExist'
 
@@ -521,6 +566,9 @@ UNSUPPORTEDOPERATION_STAFFPOOLDUPNAMEEXIST = 'UnsupportedOperation.StaffPoolDupN
 # LoRa频点还被节点或网关使用。
 UNSUPPORTEDOPERATION_STUDIOLORAFREQINUSED = 'UnsupportedOperation.StudioLoRaFreqInUsed'
 
+# TRTC增值服务未开通
+UNSUPPORTEDOPERATION_TRTCSERVICENOTOPEN = 'UnsupportedOperation.TRTCServiceNotOpen'
+
 # 账户有未支付订单。
 UNSUPPORTEDOPERATION_UNPAIDORDER = 'UnsupportedOperation.UnpaidOrder'
 
