@@ -26,6 +26,29 @@ class OrganizationClient(AbstractClient):
     _service = 'organization'
 
 
+    def AcceptJoinShareUnitInvitation(self, request):
+        """接受加入共享单元邀请。
+
+        :param request: Request instance for AcceptJoinShareUnitInvitation.
+        :type request: :class:`tencentcloud.organization.v20210331.models.AcceptJoinShareUnitInvitationRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.AcceptJoinShareUnitInvitationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("AcceptJoinShareUnitInvitation", params, headers=headers)
+            response = json.loads(body)
+            model = models.AcceptJoinShareUnitInvitationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def AddOrganizationMemberEmail(self, request):
         """添加组织成员邮箱
 
@@ -73,7 +96,7 @@ class OrganizationClient(AbstractClient):
 
 
     def AddShareUnit(self, request):
-        """创建共享单元，只有企业组织管理员可创建。
+        """创建共享单元。
 
         :param request: Request instance for AddShareUnit.
         :type request: :class:`tencentcloud.organization.v20210331.models.AddShareUnitRequest`
@@ -372,7 +395,7 @@ class OrganizationClient(AbstractClient):
 
 
     def CreatePolicy(self, request):
-        """创建一个特殊类型的策略，你可以关联到企业组织Root节点、企业单元或者企业的成员账号。
+        """创建一个特殊类型的策略，您可以关联到企业组织Root节点、企业部门节点或者企业的成员账号。
 
         :param request: Request instance for CreatePolicy.
         :type request: :class:`tencentcloud.organization.v20210331.models.CreatePolicyRequest`
@@ -487,7 +510,7 @@ class OrganizationClient(AbstractClient):
 
 
     def DeleteOrganizationMembers(self, request):
-        """批量删除企业组织成员
+        """从组织中移除成员账号，不会删除账号。
 
         :param request: Request instance for DeleteOrganizationMembers.
         :type request: :class:`tencentcloud.organization.v20210331.models.DeleteOrganizationMembersRequest`
@@ -647,6 +670,29 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeEffectivePolicy(self, request):
+        """查询目标关联的有效策略
+
+        :param request: Request instance for DescribeEffectivePolicy.
+        :type request: :class:`tencentcloud.organization.v20210331.models.DescribeEffectivePolicyRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.DescribeEffectivePolicyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeEffectivePolicy", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeEffectivePolicyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeOrganization(self, request):
         """获取企业组织信息
 
@@ -1107,6 +1153,29 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ListNonCompliantResource(self, request):
+        """获取成员标签检测不合规资源列表
+
+        :param request: Request instance for ListNonCompliantResource.
+        :type request: :class:`tencentcloud.organization.v20210331.models.ListNonCompliantResourceRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.ListNonCompliantResourceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ListNonCompliantResource", params, headers=headers)
+            response = json.loads(body)
+            model = models.ListNonCompliantResourceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ListOrganizationIdentity(self, request):
         """获取组织成员访问身份列表
 
@@ -1245,6 +1314,29 @@ class OrganizationClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RejectJoinShareUnitInvitation(self, request):
+        """拒绝加入共享单元邀请。
+
+        :param request: Request instance for RejectJoinShareUnitInvitation.
+        :type request: :class:`tencentcloud.organization.v20210331.models.RejectJoinShareUnitInvitationRequest`
+        :rtype: :class:`tencentcloud.organization.v20210331.models.RejectJoinShareUnitInvitationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RejectJoinShareUnitInvitation", params, headers=headers)
+            response = json.loads(body)
+            model = models.RejectJoinShareUnitInvitationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpdateOrganizationIdentity(self, request):
         """更新组织身份
 
