@@ -26,6 +26,29 @@ class TrtcClient(AbstractClient):
     _service = 'trtc'
 
 
+    def ControlAIConversation(self, request):
+        """提供服务端控制机器人的功能
+
+        :param request: Request instance for ControlAIConversation.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.ControlAIConversationRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.ControlAIConversationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ControlAIConversation", params, headers=headers)
+            response = json.loads(body)
+            model = models.ControlAIConversationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateCloudRecording(self, request):
         """接口说明：
         启动云端录制功能，完成房间内的音视频录制，并上传到指定的云存储。您可以通过此 API 接口把TRTC 房间中的每一路音视频流做单独的录制又或者多路视频画面合流混成一路。
@@ -129,6 +152,29 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAIConversation(self, request):
+        """查询AI对话任务状态。
+
+        :param request: Request instance for DescribeAIConversation.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeAIConversationRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeAIConversationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAIConversation", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAIConversationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAITranscription(self, request):
         """查询AI转录任务状态。
 
@@ -705,7 +751,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeTrtcUsage(self, request):
-        """获取TRTC音视频互动的用量明细。
+        """获取TRTC音视频互动的用量明细，单位:分钟。
         - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
         - 单次查询统计区间最多不能超过31天。
         - 若查询当天用量，由于统计延迟等原因，返回数据可能不够准确。
@@ -968,6 +1014,29 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def StartAIConversation(self, request):
+        """启动一个任务，机器人将进入TRTC房间，与指定成员进行AI对话
+
+        :param request: Request instance for StartAIConversation.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.StartAIConversationRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.StartAIConversationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StartAIConversation", params, headers=headers)
+            response = json.loads(body)
+            model = models.StartAIConversationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StartAITranscription(self, request):
         """这个接口调用后，后台会启动转录机器人，实时进行语音识别并下发字幕和转录消息。
         转录机器人支持两种拉流方式，通过TranscriptionMode字段控制：
@@ -1237,9 +1306,8 @@ class TrtcClient(AbstractClient):
 
 
     def StartStreamIngest(self, request):
-        """将一个在线媒体流推到TRTC房间。
-        使用此接口的前提条件：需要购买 [尊享版或旗舰版套餐包](https://cloud.tencent.com/document/product/647/85386
-        )
+        """将一个在线媒体流推到TRTC房间，更多功能说明见[输入媒体流进房](https://cloud.tencent.com/document/product/647/102957#50940aad-d90f-4473-9f46-d5dd46917653)。
+        使用输入在线媒体流功能需先订阅 [尊享版或旗舰版套餐包](https://cloud.tencent.com/document/product/647/85386) 解锁能力位。
 
         :param request: Request instance for StartStreamIngest.
         :type request: :class:`tencentcloud.trtc.v20190722.models.StartStreamIngestRequest`
@@ -1285,6 +1353,29 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def StopAIConversation(self, request):
+        """停止AI对话任务
+
+        :param request: Request instance for StopAIConversation.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.StopAIConversationRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.StopAIConversationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("StopAIConversation", params, headers=headers)
+            response = json.loads(body)
+            model = models.StopAIConversationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StopAITranscription(self, request):
         """停止AI转录任务。
 
